@@ -12,7 +12,8 @@ from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import (
     OTLPSpanExporter as GRPCExporter,
 )
 from opentelemetry.sdk.resources import Resource
-from opentelemetry.sdk.trace import TracerProvider, SpanProcessor
+from opentelemetry.sdk.trace import TracerProvider, SpanProcessor, ReadableSpan
+from opentelemetry.sdk.trace.sampling import Sampler
 from opentelemetry.propagators.textmap import TextMapPropagator
 from opentelemetry.propagate import set_global_textmap
 from opentelemetry.sdk.trace.export import (
@@ -20,7 +21,9 @@ from opentelemetry.sdk.trace.export import (
     SimpleSpanProcessor,
     BatchSpanProcessor,
 )
-from opentelemetry.trace import get_tracer_provider, ProxyTracerProvider
+from opentelemetry.context import Context
+
+from opentelemetry.trace import get_tracer_provider, ProxyTracerProvider, Span
 from opentelemetry.context import get_value, attach, set_value
 from opentelemetry.instrumentation.threading import ThreadingInstrumentor
 
@@ -31,7 +34,7 @@ from traceloop.sdk.instruments import Instruments
 from traceloop.sdk.tracing.content_allow_list import ContentAllowList
 from traceloop.sdk.utils import is_notebook
 from traceloop.sdk.utils.package_check import is_package_installed
-from typing import Callable, Dict, Optional, Set
+from typing import Callable, Dict, List, Optional, Set, Union
 
 
 TRACER_NAME = "traceloop.tracer"
@@ -66,13 +69,15 @@ class TracerWrapper(object):
     def __new__(
         cls,
         disable_batch=False,
-        processor: SpanProcessor = None,
+        processor: Optional[Union[SpanProcessor, List[SpanProcessor]]] = None,
         propagator: TextMapPropagator = None,
         exporter: SpanExporter = None,
+        sampler: Optional[Sampler] = None,
         should_enrich_metrics: bool = True,
         instruments: Optional[Set[Instruments]] = None,
         block_instruments: Optional[Set[Instruments]] = None,
         image_uploader: ImageUploader = None,
+        span_postprocess_callback: Optional[Callable[[ReadableSpan], None]] = None,
     ) -> "TracerWrapper":
         if not hasattr(cls, "instance"):
             obj = cls.instance = super(TracerWrapper, cls).__new__(cls)
@@ -81,11 +86,42 @@ class TracerWrapper(object):
 
             obj.__image_uploader = image_uploader
             obj.__resource = Resource(attributes=TracerWrapper.resource_attributes)
-            obj.__tracer_provider = init_tracer_provider(resource=obj.__resource)
-            if processor:
+            obj.__tracer_provider = init_tracer_provider(resource=obj.__resource, sampler=sampler)
+
+            # Handle multiple processors case
+            if processor is not None and isinstance(processor, list):
+                obj.__spans_processors = []
+                for proc in processor:
+                    original_on_start = proc.on_start
+
+                    def chained_on_start(span, parent_context=None, orig=original_on_start):
+                        if orig:
+                            orig(span, parent_context)
+                        obj._span_processor_on_start(span, parent_context)
+
+                    proc.on_start = chained_on_start
+                    obj.__spans_processors.append(proc)
+
+                    obj.__tracer_provider.add_span_processor(proc)
+
+                Telemetry().capture("tracer:init", {"processor": "multiple", "count": len(processor)})
+
+            # Handle single processor case (backward compatibility)
+            elif processor is not None:
                 Telemetry().capture("tracer:init", {"processor": "custom"})
                 obj.__spans_processor: SpanProcessor = processor
-                obj.__spans_processor_original_on_start = processor.on_start
+                original_on_start = obj.__spans_processor.on_start
+
+                def chained_on_start(span, parent_context=None, orig=original_on_start):
+                    obj._span_processor_on_start(span, parent_context)
+                    if orig:
+                        orig(span, parent_context)
+
+                obj.__spans_processor.on_start = chained_on_start
+
+                obj.__tracer_provider.add_span_processor(obj.__spans_processor)
+
+            # Handle default processor case
             else:
                 if exporter:
                     Telemetry().capture(
@@ -104,25 +140,24 @@ class TracerWrapper(object):
                         },
                     )
 
-                obj.__spans_exporter: SpanExporter = (
-                    exporter
-                    if exporter
-                    else init_spans_exporter(
-                        TracerWrapper.endpoint, TracerWrapper.headers
-                    )
+                obj.__spans_processor = get_default_span_processor(
+                    disable_batch=disable_batch,
+                    exporter=exporter
                 )
-                if disable_batch or is_notebook():
-                    obj.__spans_processor: SpanProcessor = SimpleSpanProcessor(
-                        obj.__spans_exporter
-                    )
-                else:
-                    obj.__spans_processor: SpanProcessor = BatchSpanProcessor(
-                        obj.__spans_exporter
-                    )
-                obj.__spans_processor_original_on_start = None
 
-            obj.__spans_processor.on_start = obj._span_processor_on_start
-            obj.__tracer_provider.add_span_processor(obj.__spans_processor)
+                if span_postprocess_callback:
+                    # Create a wrapper that calls both the custom and original methods
+                    original_on_end = obj.__spans_processor.on_end
+
+                    def wrapped_on_end(span):
+                        # Call the custom on_end first
+                        span_postprocess_callback(span)
+                        # Then call the original to ensure normal processing
+                        original_on_end(span)
+                    obj.__spans_processor.on_end = wrapped_on_end
+
+                obj.__spans_processor.on_start = obj._span_processor_on_start
+                obj.__tracer_provider.add_span_processor(obj.__spans_processor)
 
             if propagator:
                 set_global_textmap(propagator)
@@ -130,20 +165,13 @@ class TracerWrapper(object):
             # this makes sure otel context is propagated so we always want it
             ThreadingInstrumentor().instrument()
 
-            instrument_set = init_instrumentations(
+            init_instrumentations(
                 should_enrich_metrics,
                 image_uploader.aupload_base64_image,
                 instruments,
                 block_instruments,
             )
 
-            if not instrument_set:
-                print(
-                    Fore.RED + "Warning: No valid instruments set. Remove 'instrument' "
-                    "argument to use all instruments, or set a valid instrument."
-                )
-                print(Fore.RESET)
-
             obj.__content_allow_list = ContentAllowList()
 
             # Force flushes for debug environments (e.g. local development)
@@ -155,71 +183,18 @@ class TracerWrapper(object):
         self.flush()
 
     def _span_processor_on_start(self, span, parent_context):
-        workflow_name = get_value("workflow_name")
-        if workflow_name is not None:
-            span.set_attribute(SpanAttributes.TRACELOOP_WORKFLOW_NAME, workflow_name)
-
-        entity_path = get_value("entity_path")
-        if entity_path is not None:
-            span.set_attribute(SpanAttributes.TRACELOOP_ENTITY_PATH, entity_path)
+        default_span_processor_on_start(span, parent_context)
 
+        # TODO: this is here only because we need self to be able to access the content allow list
+        # we should refactor this to not need self
         association_properties = get_value("association_properties")
         if association_properties is not None:
-            _set_association_properties_attributes(span, association_properties)
-
             if not self.enable_content_tracing:
                 if self.__content_allow_list.is_allowed(association_properties):
                     attach(set_value("override_enable_content_tracing", True))
                 else:
                     attach(set_value("override_enable_content_tracing", False))
 
-        if is_llm_span(span):
-            managed_prompt = get_value("managed_prompt")
-            if managed_prompt is not None:
-                span.set_attribute(
-                    SpanAttributes.TRACELOOP_PROMPT_MANAGED, managed_prompt
-                )
-
-            prompt_key = get_value("prompt_key")
-            if prompt_key is not None:
-                span.set_attribute(SpanAttributes.TRACELOOP_PROMPT_KEY, prompt_key)
-
-            prompt_version = get_value("prompt_version")
-            if prompt_version is not None:
-                span.set_attribute(
-                    SpanAttributes.TRACELOOP_PROMPT_VERSION, prompt_version
-                )
-
-            prompt_version_name = get_value("prompt_version_name")
-            if prompt_version_name is not None:
-                span.set_attribute(
-                    SpanAttributes.TRACELOOP_PROMPT_VERSION_NAME, prompt_version_name
-                )
-
-            prompt_version_hash = get_value("prompt_version_hash")
-            if prompt_version_hash is not None:
-                span.set_attribute(
-                    SpanAttributes.TRACELOOP_PROMPT_VERSION_HASH, prompt_version_hash
-                )
-
-            prompt_template = get_value("prompt_template")
-            if prompt_template is not None:
-                span.set_attribute(
-                    SpanAttributes.TRACELOOP_PROMPT_TEMPLATE, prompt_template
-                )
-
-            prompt_template_variables = get_value("prompt_template_variables")
-            if prompt_template_variables is not None:
-                for key, value in prompt_template_variables.items():
-                    span.set_attribute(
-                        f"{SpanAttributes.TRACELOOP_PROMPT_TEMPLATE_VARIABLES}.{key}",
-                        value,
-                    )
-
-        # Call original on_start method if it exists in custom processor
-        if self.__spans_processor_original_on_start:
-            self.__spans_processor_original_on_start(span, parent_context)
-
     @staticmethod
     def set_static_params(
         resource_attributes: dict,
@@ -255,7 +230,11 @@ class TracerWrapper(object):
         cls.__disabled = disabled
 
     def flush(self):
-        self.__spans_processor.force_flush()
+        if hasattr(self, '_TracerWrapper__spans_processor'):
+            self.__spans_processor.force_flush()
+        elif hasattr(self, '_TracerWrapper__spans_processors'):
+            for processor in self.__spans_processors:
+                processor.force_flush()
 
     def get_tracer(self):
         return self.__tracer_provider.get_tracer(TRACER_NAME)
@@ -328,12 +307,108 @@ def init_spans_exporter(api_endpoint: str, headers: Dict[str, str]) -> SpanExpor
         return GRPCExporter(endpoint=f"{api_endpoint}", headers=headers)
 
 
-def init_tracer_provider(resource: Resource) -> TracerProvider:
+def default_span_processor_on_start(span: Span, parent_context: Context | None = None):
+    """
+    Same as _span_processor_on_start but without the usage of self which comes from the sdk, good for standalone usage.
+    """
+    workflow_name = get_value("workflow_name")
+    if workflow_name is not None:
+        span.set_attribute(SpanAttributes.TRACELOOP_WORKFLOW_NAME, str(workflow_name))
+
+    entity_path = get_value("entity_path")
+    if entity_path is not None:
+        span.set_attribute(SpanAttributes.TRACELOOP_ENTITY_PATH, str(entity_path))
+
+    association_properties = get_value("association_properties")
+    if association_properties is not None and isinstance(association_properties, dict):
+        _set_association_properties_attributes(span, association_properties)
+
+    if is_llm_span(span):
+        managed_prompt = get_value("managed_prompt")
+        if managed_prompt is not None:
+            span.set_attribute(
+                SpanAttributes.TRACELOOP_PROMPT_MANAGED, str(managed_prompt)
+            )
+
+        prompt_key = get_value("prompt_key")
+        if prompt_key is not None:
+            span.set_attribute(SpanAttributes.TRACELOOP_PROMPT_KEY, str(prompt_key))
+
+        prompt_version = get_value("prompt_version")
+        if prompt_version is not None:
+            span.set_attribute(
+                SpanAttributes.TRACELOOP_PROMPT_VERSION, str(prompt_version)
+            )
+
+        prompt_version_name = get_value("prompt_version_name")
+        if prompt_version_name is not None:
+            span.set_attribute(
+                SpanAttributes.TRACELOOP_PROMPT_VERSION_NAME, str(prompt_version_name)
+            )
+
+        prompt_version_hash = get_value("prompt_version_hash")
+        if prompt_version_hash is not None:
+            span.set_attribute(
+                SpanAttributes.TRACELOOP_PROMPT_VERSION_HASH, str(prompt_version_hash)
+            )
+
+        prompt_template = get_value("prompt_template")
+        if prompt_template is not None:
+            span.set_attribute(
+                SpanAttributes.TRACELOOP_PROMPT_TEMPLATE, str(prompt_template)
+            )
+
+        prompt_template_variables = get_value("prompt_template_variables")
+        if prompt_template_variables is not None and isinstance(prompt_template_variables, dict):
+            for key, value in prompt_template_variables.items():
+                span.set_attribute(
+                    f"{SpanAttributes.TRACELOOP_PROMPT_TEMPLATE_VARIABLES}.{key}",
+                    value,
+                )
+
+
+def get_default_span_processor(
+    disable_batch: bool = False,
+    api_endpoint: Optional[str] = None,
+    headers: Optional[Dict[str, str]] = None,
+    exporter: Optional[SpanExporter] = None
+) -> SpanProcessor:
+    """
+    Creates and returns the default Traceloop span processor.
+
+    Args:
+        disable_batch: If True, uses SimpleSpanProcessor, otherwise BatchSpanProcessor
+        api_endpoint: The endpoint URL for the exporter (uses TracerWrapper.endpoint if None)
+        headers: Headers for the exporter (uses TracerWrapper.headers if None)
+        exporter: Custom exporter to use (creates default if None)
+
+    Returns:
+        SpanProcessor: The default Traceloop span processor
+    """
+    endpoint = api_endpoint or TracerWrapper.endpoint
+    request_headers = headers or TracerWrapper.headers
+
+    spans_exporter = exporter or init_spans_exporter(endpoint, request_headers)
+
+    if disable_batch or is_notebook():
+        processor = SimpleSpanProcessor(spans_exporter)
+    else:
+        processor = BatchSpanProcessor(spans_exporter)
+
+    setattr(processor, "_traceloop_processor", True)
+    processor.on_start = default_span_processor_on_start
+    return processor
+
+
+def init_tracer_provider(resource: Resource, sampler: Optional[Sampler] = None) -> TracerProvider:
     provider: TracerProvider = None
     default_provider: TracerProvider = get_tracer_provider()
 
     if isinstance(default_provider, ProxyTracerProvider):
-        provider = TracerProvider(resource=resource)
+        if sampler is not None:
+            provider = TracerProvider(resource=resource, sampler=sampler)
+        else:
+            provider = TracerProvider(resource=resource)
         trace.set_tracer_provider(provider)
     elif not hasattr(default_provider, "add_span_processor"):
         logging.error(
@@ -403,6 +478,9 @@ def init_instrumentations(
         elif instrument == Instruments.MARQO:
             if init_marqo_instrumentor():
                 instrument_set = True
+        elif instrument == Instruments.MCP:
+            if init_mcp_instrumentor():
+                instrument_set = True
         elif instrument == Instruments.MILVUS:
             if init_milvus_instrumentor():
                 instrument_set = True
@@ -415,6 +493,9 @@ def init_instrumentations(
         elif instrument == Instruments.OPENAI:
             if init_openai_instrumentor(should_enrich_metrics, base64_image_uploader):
                 instrument_set = True
+        elif instrument == Instruments.OPENAI_AGENTS:
+            if init_openai_agents_instrumentor():
+                instrument_set = True
         elif instrument == Instruments.PINECONE:
             if init_pinecone_instrumentor():
                 instrument_set = True
@@ -454,9 +535,6 @@ def init_instrumentations(
         elif instrument == Instruments.WEAVIATE:
             if init_weaviate_instrumentor():
                 instrument_set = True
-        elif instrument == Instruments.MCP:
-            if init_mcp_instrumentor():
-                instrument_set = True
         else:
             print(Fore.RED + f"Warning: {instrument} instrumentation does not exist.")
             print(
@@ -470,7 +548,8 @@ def init_instrumentations(
         print(
             Fore.RED
             + "Warning: No valid instruments set. "
-            + "Specify instruments or remove 'instruments' argument to use all instruments."
+            + "Ensure the instrumented libraries are installed, specify valid instruments, "
+            + "or remove 'instruments' argument to use all instruments."
         )
         print(Fore.RESET)
 
@@ -488,18 +567,17 @@ def init_openai_instrumentor(
             instrumentor = OpenAIInstrumentor(
                 exception_logger=lambda e: Telemetry().log_exception(e),
                 enrich_assistant=should_enrich_metrics,
-                enrich_token_usage=should_enrich_metrics,
                 get_common_metrics_attributes=metrics_common_attributes,
                 upload_base64_image=base64_image_uploader,
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
 
     except Exception as e:
         logging.error(f"Error initializing OpenAI instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_anthropic_instrumentor(
@@ -518,11 +596,11 @@ def init_anthropic_instrumentor(
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Anthropic instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_cohere_instrumentor():
@@ -536,11 +614,11 @@ def init_cohere_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Cohere instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_pinecone_instrumentor():
@@ -554,16 +632,16 @@ def init_pinecone_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Pinecone instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_qdrant_instrumentor():
     try:
-        if is_package_installed("qdrant_client"):
+        if is_package_installed("qdrant_client") or is_package_installed("qdrant-client"):
             Telemetry().capture("instrumentation:qdrant:init")
             from opentelemetry.instrumentation.qdrant import QdrantInstrumentor
 
@@ -572,10 +650,11 @@ def init_qdrant_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
+            return True
     except Exception as e:
         logging.error(f"Error initializing Qdrant instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_chroma_instrumentor():
@@ -589,16 +668,16 @@ def init_chroma_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Chroma instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_google_generativeai_instrumentor():
     try:
-        if is_package_installed("google-generativeai"):
+        if is_package_installed("google-generativeai") or is_package_installed("google-genai"):
             Telemetry().capture("instrumentation:gemini:init")
             from opentelemetry.instrumentation.google_generativeai import (
                 GoogleGenerativeAiInstrumentor,
@@ -609,11 +688,11 @@ def init_google_generativeai_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Gemini instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_haystack_instrumentor():
@@ -627,16 +706,16 @@ def init_haystack_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Haystack instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_langchain_instrumentor():
     try:
-        if is_package_installed("langchain"):
+        if is_package_installed("langchain") or is_package_installed("langgraph"):
             Telemetry().capture("instrumentation:langchain:init")
             from opentelemetry.instrumentation.langchain import LangchainInstrumentor
 
@@ -645,11 +724,11 @@ def init_langchain_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing LangChain instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_mistralai_instrumentor():
@@ -663,11 +742,11 @@ def init_mistralai_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing MistralAI instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_ollama_instrumentor():
@@ -681,11 +760,11 @@ def init_ollama_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Ollama instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_transformers_instrumentor():
@@ -701,11 +780,11 @@ def init_transformers_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Transformers instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_together_instrumentor():
@@ -719,11 +798,11 @@ def init_together_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing TogetherAI instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_llama_index_instrumentor():
@@ -737,11 +816,11 @@ def init_llama_index_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing LlamaIndex instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_milvus_instrumentor():
@@ -755,11 +834,11 @@ def init_milvus_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Milvus instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_requests_instrumentor():
@@ -770,11 +849,11 @@ def init_requests_instrumentor():
             instrumentor = RequestsInstrumentor()
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument(excluded_urls=EXCLUDED_URLS)
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Requests instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_urllib3_instrumentor():
@@ -785,11 +864,11 @@ def init_urllib3_instrumentor():
             instrumentor = URLLib3Instrumentor()
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument(excluded_urls=EXCLUDED_URLS)
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing urllib3 instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_pymysql_instrumentor():
@@ -800,11 +879,11 @@ def init_pymysql_instrumentor():
             instrumentor = SQLAlchemyInstrumentor()
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing SQLAlchemy instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_bedrock_instrumentor(should_enrich_metrics: bool):
@@ -818,11 +897,11 @@ def init_bedrock_instrumentor(should_enrich_metrics: bool):
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Bedrock instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_sagemaker_instrumentor(should_enrich_metrics: bool):
@@ -832,15 +911,14 @@ def init_sagemaker_instrumentor(should_enrich_metrics: bool):
 
             instrumentor = SageMakerInstrumentor(
                 exception_logger=lambda e: Telemetry().log_exception(e),
-                enrich_token_usage=should_enrich_metrics,
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing SageMaker instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_replicate_instrumentor():
@@ -854,11 +932,11 @@ def init_replicate_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Replicate instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_vertexai_instrumentor():
@@ -872,11 +950,11 @@ def init_vertexai_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.warning(f"Error initializing Vertex AI instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_watsonx_instrumentor():
@@ -892,11 +970,11 @@ def init_watsonx_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.warning(f"Error initializing Watsonx instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_weaviate_instrumentor():
@@ -910,11 +988,11 @@ def init_weaviate_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.warning(f"Error initializing Weaviate instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_alephalpha_instrumentor():
@@ -928,11 +1006,11 @@ def init_alephalpha_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Aleph Alpha instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_marqo_instrumentor():
@@ -946,11 +1024,11 @@ def init_marqo_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing marqo instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_lancedb_instrumentor():
@@ -964,9 +1042,11 @@ def init_lancedb_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing LanceDB instrumentor: {e}")
+        Telemetry().log_exception(e)
+    return False
 
 
 def init_redis_instrumentor():
@@ -977,11 +1057,11 @@ def init_redis_instrumentor():
             instrumentor = RedisInstrumentor()
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument(excluded_urls=EXCLUDED_URLS)
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing redis instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_groq_instrumentor():
@@ -995,11 +1075,11 @@ def init_groq_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing Groq instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_crewai_instrumentor():
@@ -1013,11 +1093,11 @@ def init_crewai_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing CrewAI instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
 
 
 def init_mcp_instrumentor():
@@ -1031,11 +1111,31 @@ def init_mcp_instrumentor():
             )
             if not instrumentor.is_instrumented_by_opentelemetry:
                 instrumentor.instrument()
-        return True
+            return True
     except Exception as e:
         logging.error(f"Error initializing MCP instrumentor: {e}")
         Telemetry().log_exception(e)
-        return False
+    return False
+
+
+def init_openai_agents_instrumentor():
+    try:
+        if is_package_installed("openai-agents"):
+            Telemetry().capture("instrumentation:openai_agents:init")
+            from opentelemetry.instrumentation.openai_agents import (
+                OpenAIAgentsInstrumentor,
+            )
+
+            instrumentor = OpenAIAgentsInstrumentor(
+                exception_logger=lambda e: Telemetry().log_exception(e),
+            )
+            if not instrumentor.is_instrumented_by_opentelemetry:
+                instrumentor.instrument()
+            return True
+    except Exception as e:
+        logging.error(f"Error initializing OpenAI Agents instrumentor: {e}")
+        Telemetry().log_exception(e)
+    return False
 
 
 def metrics_common_attributes():
